/**********************************************************************/
/*                                                                    */
/*  ARSCSXIT.H :    OnDemand User Exit Declarations                   */
/*                                                                    */
/*  This file contains function and structure declarations for        */
/*  the OnDemand user exits.                                          */
/*                                                                    */
/* COPYRIGHT:                                                         */
/*  5697-G34 (C) COPYRIGHT IBM CORPORATION 2001                       */
/*  All Rights Reserved                                               */
/*  Licensed Materials - Property of IBM                              */
/*                                                                    */
/*  US Government Users Restricted Rights - Use, duplication or       */
/*  disclosure restricted by GSA ADP Schedule Contract with IBM Corp. */
/*                                                                    */
/* NOTE: This program sample is provided on an as-is basis.           */
/*       The licensee of the OnDemand product is free to copy, revise,*/
/*       modify, and make derivative works of this program sample     */
/*       as they see fit.                                             */
/*                                                                    */
/**********************************************************************/
#ifndef _ARSCSXIT_H
#define _ARSCSXIT_H

#ifdef __cplusplus
extern "C" {
#endif

#if defined(WIN32)
 #include <windows.h>
 #define ARSCSXIT_API
 #define ARSCSXIT_APIFUNC ARSCSXIT_API *
 #define ARSCSXIT_EXPORT  __declspec( dllexport )
#elif defined(OS390)
 #define ARSCSXIT_API
 #define ARSCSXIT_APIFUNC * ARSCSXIT_API
 #ifdef __cplusplus
  #define ARSCSXIT_EXPORT _Export
 #else
  #define ARSCSXIT_EXPORT
 #endif
#else
 #define ARSCSXIT_API
 #define ARSCSXIT_APIFUNC * ARSCSXIT_API
 #define ARSCSXIT_EXPORT
#endif

#if defined(AIX) || defined(HPUX) || defined(SUNOS) || defined(LINUX) \
                 || defined(__OS400__) || defined(OS390)

typedef long long ArcCSXitBigInt;

#elif defined(WIN32)

typedef __int64 ArcCSXitBigInt;

#else

typedef long ArcCSXitBigInt;

#endif

#include <limits.h>

/*********************************************************************/
/* FAX OPTIONS STRUCTURES                                            */
/*********************************************************************/
#define ARSCSXIT_FAX_RECIPIENT_ATTN_MAX    50
#define ARSCSXIT_FAX_RECIPIENT_COMPANY_MAX 50
#define ARSCSXIT_FAX_RECIPIENT_FAX_MAX     32
#define ARSCSXIT_FAX_SENDER_FROM_MAX       50
#define ARSCSXIT_FAX_SENDER_COMPANY_MAX    50
#define ARSCSXIT_FAX_SENDER_PHONE_MAX      32
#define ARSCSXIT_FAX_SENDER_FAX_MAX        32
#define ARSCSXIT_FAX_SENDER_COVERPAGE_MAX  8

typedef struct _ArsCSXitFaxOptions
{
   char recipient_attn[ARSCSXIT_FAX_RECIPIENT_ATTN_MAX + 1];
   char recipient_company[ARSCSXIT_FAX_RECIPIENT_COMPANY_MAX + 1];
   char recipient_fax[ARSCSXIT_FAX_RECIPIENT_FAX_MAX + 1];
   char sender_name[ARSCSXIT_FAX_SENDER_FROM_MAX + 1];
   char sender_company[ARSCSXIT_FAX_SENDER_COMPANY_MAX + 1];
   char sender_phone[ARSCSXIT_FAX_SENDER_PHONE_MAX + 1];
   char sender_fax[ARSCSXIT_FAX_SENDER_FAX_MAX + 1];
   char sender_coverpage[ARSCSXIT_FAX_SENDER_COVERPAGE_MAX + 1];
} ArsCSXitFaxOptions;

/*********************************************************************/
/* SECURITY STRUCTURES                                               */
/*********************************************************************/
typedef enum _ArcCSXitSecurityAction
{
   ARCCSXIT_SECURITY_USER_LOGIN,
   ARCCSXIT_SECURITY_USER_ADD,
   ARCCSXIT_SECURITY_USER_DELETE,
   ARCCSXIT_SECURITY_USER_UPDATE
} ArcCSXitSecurityAction;

typedef enum _ArcCSXitSecurityRC
{
   ARCCSXIT_SECURITY_RC_OKAY,
   ARCCSXIT_SECURITY_RC_PERMS,
   ARCCSXIT_SECURITY_RC_PASSWD_CHNG,
   ARCCSXIT_SECURITY_RC_FAILED,
   ARCCSXIT_SECURITY_RC_OKAY_BUT_VALIDATE_IN_OD
} ArcCSXitSecurityRC;

/* DKW - LI830 */
/*********************************************************************/
/* UPDATE REPORT DEFINITIONS STRUCTURES                              */
/*********************************************************************/
#define ARCCSXIT_PROCESS_NAMES 1
#define ARCCSXIT_PROCESS_PARMS 2

#define ARCCSXIT_MAX_NAME_SIZE         60
#define ARCCSXIT_MAX_SERVER_SIZE      254
#define ARCCSXIT_MAX_INDEXER_SIZE   32700
#define ARCCSXIT_MAX_DELIMITER_SIZE    16
/* DKW - LI830 */

/*********************************************************************/
/* COMMON STRUCTURES                                                 */
/*********************************************************************/
#define ARCCSXIT_MAX_SRVR_MESSAGE_SIZE 1024

/* DKW - LI832 */
#if defined(WIN16) || defined(WIN32) || defined(OS2)
 #define ARCCSXIT_PATH_MAX _MAX_PATH
#elif defined(AIX) || defined(SUNOS) || defined(LINUX)
 #define ARCCSXIT_PATH_MAX PATH_MAX
#elif defined(HPUX)
 #define ARCCSXIT_PATH_MAX _POSIX_PATH_MAX
#elif defined(OS390)
 #define ARCCSXIT_PATH_MAX 1023
#else
 #define ARCCSXIT_PATH_MAX 1024
#endif
/* DKW - LI832 */

typedef struct _ArcCSXitApplGroup
{
   char *name;
   long agid;
   char *agid_name;
} ArcCSXitApplGroup;

typedef unsigned char ArcCSXitDocType;
#define ARCCSXIT_DOC_TYPE_AFP     (ArcCSXitDocType) 0x41
#define ARCCSXIT_DOC_TYPE_BMP     (ArcCSXitDocType) 0x42
/* DKW - LI832 */
#define ARCCSXIT_DOC_TYPE_EMAIL   (ArcCSXitDocType) 0x45
/* DKW - LI832 */
#define ARCCSXIT_DOC_TYPE_GIF     (ArcCSXitDocType) 0x47
#define ARCCSXIT_DOC_TYPE_JFIF    (ArcCSXitDocType) 0x4A
/* DKW - LI1469 */
#define ARCCSXIT_DOC_TYPE_DJDE    (ArcCSXitDocType) 0x4B
/* DKW - LI1469 */
#define ARCCSXIT_DOC_TYPE_LINE    (ArcCSXitDocType) 0x4C
#define ARCCSXIT_DOC_TYPE_META    (ArcCSXitDocType) 0x4D
#define ARCCSXIT_DOC_TYPE_NONE    (ArcCSXitDocType) 0x4E
/* DKW - LI832 */
#define ARCCSXIT_DOC_TYPE_ODDOC   (ArcCSXitDocType) 0x4F
/* DKW - LI832 */
#define ARCCSXIT_DOC_TYPE_PCX     (ArcCSXitDocType) 0x50
#define ARCCSXIT_DOC_TYPE_PDF     (ArcCSXitDocType) 0x52
#define ARCCSXIT_DOC_TYPE_PNG     (ArcCSXitDocType) 0x51
#define ARCCSXIT_DOC_TYPE_SCS     (ArcCSXitDocType) 0x53
#define ARCCSXIT_DOC_TYPE_SCS_EXT (ArcCSXitDocType) 0x58
#define ARCCSXIT_DOC_TYPE_TIFF    (ArcCSXitDocType) 0x54
#define ARCCSXIT_DOC_TYPE_USRDEF  (ArcCSXitDocType) 0x55

typedef unsigned char ArcCSXitDocFormat;
#define ARCCSXIT_DOC_FORMAT_FIXED    (ArcCSXitDocFormat) 0x00
#define ARCCSXIT_DOC_FORMAT_VARIABLE (ArcCSXitDocFormat) 0x01
#define ARCCSXIT_DOC_FORMAT_STREAM   (ArcCSXitDocFormat) 0x02

/* DKW - LI830 */
typedef unsigned char ArcCSXitCarCtl;
#define ARCCSXIT_CC_ANSI    (ArcCSXitCarCtl) 'A'
#define ARCCSXIT_CC_MACHINE (ArcCSXitCarCtl) 'M'
#define ARCCSXIT_CC_NONE    (ArcCSXitCarCtl) 'N'
/* DKW - LI830 */

/* DKW - LI832 */
typedef unsigned char ArcCSXitPrMode;
#define ARCCSXIT_PRMODE_NONE   (ArcCSXitPrMode)'N'
#define ARCCSXIT_PRMODE_SOSI1  (ArcCSXitPrMode)'1'
#define ARCCSXIT_PRMODE_SOSI2  (ArcCSXitPrMode)'2'
#define ARCCSXIT_PRMODE_SOSI3  (ArcCSXitPrMode)'3'
/* DKW - LI832 */

typedef struct _ArcCSXitAppl
{
   char              *name;
   long              aid;
   ArcCSXitDocType   doc_type;
   ArcCSXitDocFormat doc_fmt;     /* Document Format for Linedata */
   union
   {
      int  fixed;                 /* Fixed - Record Length */
      char stream[17];            /* Stream - Character Delimiters */
   } u;
/* DKW - LI832 */
   unsigned char    trc_present;  /* 0 = no, 1 = yes */
   int              line_count;   /* Lines per page for line data */
   int              code_page;    /* Code Page for line data */
   ArcCSXitCarCtl   cc_type;      /* CC type for line data */
   ArcCSXitPrMode   prmode;       /* PRMode for line data */
/* DKW - LI832 */

} ArcCSXitAppl;

typedef unsigned char ArcCSXitFieldType;
#define ARCCSXIT_FIELD_TYPE_BIGINT   (ArcCSXitFieldType) 0x42
#define ARCCSXIT_FIELD_TYPE_DECIMAL  (ArcCSXitFieldType) 0x44
#define ARCCSXIT_FIELD_TYPE_INTEGER  (ArcCSXitFieldType) 0x49
#define ARCCSXIT_FIELD_TYPE_SMALLINT (ArcCSXitFieldType) 0x4E
#define ARCCSXIT_FIELD_TYPE_STRING   (ArcCSXitFieldType) 0x53

typedef unsigned char ArcCSXitFieldTypeQual;
#define ARCCSXIT_FIELD_TYPE_QUAL_BASE       (ArcCSXitFieldTypeQual) 0x42
#define ARCCSXIT_FIELD_TYPE_QUAL_DATETIME   (ArcCSXitFieldTypeQual) 0x43
#define ARCCSXIT_FIELD_TYPE_QUAL_DATE       (ArcCSXitFieldTypeQual) 0x44
#define ARCCSXIT_FIELD_TYPE_QUAL_TIME       (ArcCSXitFieldTypeQual) 0x54
#define ARCCSXIT_FIELD_TYPE_QUAL_TZ_DATETIME \
                                            (ArcCSXitFieldTypeQual) 0x5A

typedef struct _ArcCSXitField
{
   char                  *db_name;
   ArcCSXitFieldType     type;
   ArcCSXitFieldTypeQual qual;
   union
   {
      double         d;
      ArcCSXitBigInt b;
      long           i;
      short          n;
      char           *str;
   } u;
} ArcCSXitField;

typedef struct _ArcCSXitDocFields
{
   int           flds_num;
   ArcCSXitField *flds;
} ArcCSXitDocFields;

#define ARCCSXIT_DOCNAME_SIZE 11

typedef struct _ArcCSXitDocHandle
{
   char          name[ARCCSXIT_DOCNAME_SIZE + 1];
   unsigned long doc_off;
   unsigned long doc_len;
   unsigned long comp_off;
   unsigned long comp_len;
} ArcCSXitDocHandle;

typedef struct _ArcCSXitDoc
{
   ArcCSXitDocFields doc_flds;
   ArcCSXitDocHandle doc_hndl;
} ArcCSXitDoc;

/*********************************************************************/
/* FUNCTION DECLARATIONS                                             */
/*********************************************************************/

/**********************************************************************/
/* FAXOPTS - Fax Options Exit                                         */
/*                                                                    */
/*  This exit is for specialized applications and is not normally     */
/*  used.                                                             */
/*                                                                    */
/* INPUT: appl_grp                                                    */
/*        doc_flds                                                    */
/*                                                                    */
/* OUTPUT:                                                            */
/*        exitdata                                                    */
/*                                                                    */
/* RETURN_CODE:                                                       */
/*        0         -> Successful                                     */
/*        Otherwise -> Failed                                         */
/*                                                                    */
/**********************************************************************/
int
ARSCSXIT_EXPORT
ARSCSXIT_API
FAXOPTS( ArcCSXitApplGroup *appl_grp,
         ArcCSXitDocFields *doc_flds,
         ArsCSXitFaxOptions *exitdata
       );

/**********************************************************************/
/* SECURITY - Security Exit                                           */
/*                                                                    */
/*  To activate the security exit, set the following variable in the  */
/*  appropriate OnDemand instance section in the ars.ini file:        */
/*                                                                    */
/*    SRVR_FLAGS_SECURITY_EXIT=1                                      */
/*                                                                    */
/* 1) User Login                                                      */
/*      On Input:  action == ARCCSXIT_SECURITY_USER_LOGIN             */
/*                                                                    */
/*    INPUT: cur_userid - Userid                                      */
/*           cur_passwd - Password                                    */
/*                                                                    */
/*    OUTPUT:                                                         */
/*                                                                    */
/* 2) User Add                                                        */
/*      On Input:  action == ARCCSXIT_SECURITY_USER_ADD               */
/*                                                                    */
/*    INPUT: act_userid - Actual User doing the add                   */
/*           new_userid - Userid to add                               */
/*           new_passwd - Password                                    */
/*                                                                    */
/*    OUTPUT:                                                         */
/*                                                                    */
/* 3) User Delete                                                     */
/*      On Input:  action == ARCCSXIT_SECURITY_USER_DELETE            */
/*                                                                    */
/*    INPUT: act_userid - Actual User doing the delete                */
/*           cur_userid - Userid to delete                            */
/*                                                                    */
/*    OUTPUT:                                                         */
/*                                                                    */
/* 4) User Update                                                     */
/*      On Input:  action == ARCCSXIT_SECURITY_USER_UPDATE            */
/*                                                                    */
/*    INPUT: act_userid - Actual User doing the update                */
/*           cur_userid - Current userid                              */
/*           cur_passwd - Current password                            */
/*           new_userid - New userid                                  */
/*           new_passwd - New Password                                */
/*                        If NULL, then no password change            */
/*                                                                    */
/*    OUTPUT:                                                         */
/*                                                                    */
/* RETURN_CODE:                                                       */
/*        ARCCSXIT_SECURITY_RC_OKAY        -> Successful              */
/*        ARCCSXIT_SECURITY_RC_PERMS       -> No permission.          */
/*        ARCCSXIT_SECURITY_RC_PASSWD_CHNG -> Only valid on Login.    */
/*                                            Login is successful,    */
/*                                            password must be        */
/*                                            changed.                */
/*        ARCCSXIT_SECURITY_RC_FAILED      -> Failed                  */
/*                                                                    */
/* NOTES:  (output) msg is ARCCSXIT_MAX_SRVR_MESSAGE_SIZE bytes in    */
/*         size.  If the return code != ARCCSXIT_SECURITY_RC_OKAY     */
/*         then if msg[0] != '\0', then this will be the message      */
/*         displayed by the client.  Otherwise the client will use    */
/*         its native message text.                                   */
/*                                                                    */
/**********************************************************************/
ArcCSXitSecurityRC
ARSCSXIT_EXPORT
ARSCSXIT_API
SECURITY( char *act_userid,
          char *cur_userid,
          char *cur_passwd,
          char *new_userid,
          char *new_passwd,
          ArcCSXitSecurityAction action,
          char *msg
        );

/**********************************************************************/
/* SMEXTCAC - Storage Management External Cache Exit                  */
/*                                                                    */
/*  This exit is invoked only when data is to be retrieved from an    */
/*  Application Group that is defined with the External Cache setting */
/*  checked.  This exit is for specialized applications and is not    */
/*  normally used.                                                    */
/*                                                                    */
/* 1) Don't return data, only validate whether the document exists.   */
/*      On Input:  buf == NULL                                        */
/*                                                                    */
/*    INPUT: appl_grp                                                 */
/*           doc                                                      */
/*           buf                                                      */
/*                                                                    */
/*    OUTPUT:                                                         */
/*           *buf_len = 0 -> Data is not in external cache            */
/*                        -> Otherwise data is in external cache      */
/*                                                                    */
/* 2) Return document data.                                           */
/*      On Input:  buf != NULL                                        */
/*                                                                    */
/*    INPUT: appl_grp                                                 */
/*           doc                                                      */
/*           *buf_len -> #of bytes to retrieve                        */
/*                                                                    */
/*    OUTPUT:                                                         */
/*           *buf     -> Allocated memory and document data.          */
/*                       Memory is freed by OnDemand using the        */
/*                       free() function                              */
/*           *buf_len -> Length of *buf (should be same as on input)  */
/*                    -> If 0, then data does not exist within        */
/*                       external cache.                              */
/*                                                                    */
/* RETURN_CODE:                                                       */
/*        0         -> Successful                                     */
/*        Otherwise -> Failed                                         */
/*                                                                    */
/**********************************************************************/
int
ARSCSXIT_EXPORT
ARSCSXIT_API
SMEXTCAC( ArcCSXitApplGroup *appl_grp,
          ArcCSXitDoc *doc,
          char **buf,
          unsigned long *buf_len
        );

/**********************************************************************/
/* TBLSPCRT - Tablespace Create Exit                                  */
/*                                                                    */
/*  To activate the tablespace creation exit, set the following       */
/*  variable in the appropriate OnDemand instance ars.cfg file:       */
/*                                                                    */
/*    ARS_DB_TABLESPACE_USEREXIT=<absolute_dll_path_name>             */
/*                                                                    */
/* INPUT: appl_grp                                                    */
/*        tblsp_name                                                  */
/*        table_name                                                  */
/*        create_table_sql                                            */
/*        action                                                      */
/*                                                                    */
/* OUTPUT:                                                            */
/*                                                                    */
/*        1) OnDemand will invoke the exit with action == 1           */
/*           so that the exit can create the tablespace (tblsp_name)  */
/*            *created  -> 0 exit did not create the tablespace,      */
/*                           OnDemand needs to create the tablespace  */
/*            *created  -> 1 exit created the tablespace              */
/*                                                                    */
/*        2) OnDemand will then invoke the exit with action == 2      */
/*           so that the exit can create the table (table_name)       */
/*           inside of the tablespace (tblsp_name) using              */
/*           (sql)                                                    */
/*            *created  -> 0 exit did not create the table,           */
/*                           OnDemand needs to create the table       */
/*            *created  -> 1 exit created the table                   */
/*                                                                    */
/*        3) OnDemand will then invoke the exit with action == 3      */
/*           so that the exit can create the table indexes (idx_name) */
/*           inside of the tablespace (tblsp_name) for table          */
/*           (table_name) using (sql).  This will be invoked based    */
/*           on the number of indexes to create for the appl_grp      */
/*            *created  -> 0 exit did not create the index,           */
/*                           OnDemand needs to create the index       */
/*            *created  -> 1 exit created the index                   */
/*                                                                    */
/*        4) OnDemand will then invoke the exit with action == 4      */
/*           so that the exit can perform any additional work         */
/*            *created  -> Is not used                                */
/*                                                                    */
/* RETURN_CODE:                                                       */
/*        0         -> Successful                                     */
/*        Otherwise -> Failed                                         */
/*                                                                    */
/**********************************************************************/
int
ARSCSXIT_EXPORT
ARSCSXIT_API
TBLSPCRT( ArcCSXitApplGroup *appl_grp,
          char *tblsp_name,
          char *table_name,
          char *idx_name,
          char *sql,
          int action,
          int *created
        );

/**********************************************************************/
/* LOADEXIT - Load Exit                                               */
/*                                                                    */
/*  To activate the load exit, the arsuload dll must exist in the     */
/*  OnDemand exits installation directory.                            */
/*                                                                    */
/* INPUT: load                                                        */
/*                                                                    */
/* OUTPUT:                                                            */
/*        None                                                        */
/*                                                                    */
/* RETURN_CODE:                                                       */
/*        0         -> Successful                                     */
/*        Otherwise -> Failed                                         */
/*                                                                    */
/**********************************************************************/
typedef struct _ArsCSXitLoadExit
{
   char              *hostname;   /* OnDemand Library Server Hostname */
   char              *load_id;    /* Load Id */
   unsigned long     bytes;       /* Number of document bytes stored */
   unsigned long     res_bytes;   /* Number of resource bytes stored */
   ArcCSXitApplGroup *appl_grp;   /* Application Group Info */
   ArcCSXitAppl      *appl;       /* Application Info */
   char              *file;       /* File containing all rows */
   char              *user_def;   /* User Specified string to load */
} ArsCSXitLoadExit;

int
ARSCSXIT_EXPORT
ARSCSXIT_API
LOADEXIT( ArsCSXitLoadExit *load );

/**********************************************************************/
/* PERMEXIT - Permission Exit                                         */
/*                                                                    */
/*  To activate the permission exit on folder and application groups, */
/*  set the following variable in ars.ini:                            */
/*    SRVR_FLAGS_FOLDER_APPLGRP_EXIT=1 in ars.ini                     */
/*                                                                    */
/*  To activate the permission exit on documents, set the following   */
/*  variable in ars.ini (please note that this exit can greatly       */
/*  decrease OnDemand performance when performing a document query):  */
/*    SRVR_FLAGS_DOCUMENT_EXIT=1                                      */
/*                                                                    */
/*  To activate the permission exit on the sql query string, set the  */
/*  following variable in ars.ini:                                    */
/*    SRVR_FLAGS_SQL_QUERY_EXIT=1 in ars.ini                          */
/*                                                                    */
/* INPUT: userid                                                      */
/*        perm_exit                                                   */
/*                                                                    */
/* OUTPUT:                                                            */
/*        Check Folder                                                */
/*        action == 1 (folder_perm)                                   */
/*          Access to Folder using folder_name                        */
/*           *access  -> 0 no access                                  */
/*           *access  -> 1 defaults to *PUBLIC access                 */
/*           *access  -> 2 grants access/primary folder               */
/*           *access  -> 3 grants access/secondary folder             */
/*                                                                    */
/*        Check Application Group                                     */
/*        action == 2 (appl_grp_perm)                                 */
/*          Access to Application Group using appl_grp                */
/*           *access  -> 0 no access                                  */
/*           *access  -> 1 defaults to *PUBLIC access                 */
/*           *access  -> 2 grants access                              */
/*                                                                    */
/*        Check Document                                              */
/*        action == 3 (doc_perm)                                      */
/*          Access to Document using appl_grp and doc                 */
/*           *access  -> 0 no access                                  */
/*           *access  -> 1 grants access                              */
/*                                                                    */
/*        SQL Query String                                            */
/*        action == 4 (sql_query_perm)                                */
/*          Do not change the inp_sql or inp_sql_r values             */
/*           *access  -> Is not used                                  */
/*                                                                    */
/*          To Change the input SQL Query String                      */
/*           Allocate and set the new string to out_sql               */
/*           Otherwise set out_sql = NULL and in_sql will be used     */
/*                                                                    */
/*          To Change the input SQL Query Restriction String          */
/*           Allocate and set the new string to out_sql_r             */
/*           Otherwise set out_sql_r = NULL and in_sql_r will be used */
/*                                                                    */
/* RETURN_CODE:                                                       */
/*        0         -> Successful                                     */
/*        Otherwise -> Failed                                         */
/*                                                                    */
/**********************************************************************/

typedef struct _ArcCSXitPermExit
{
   /*
    * action
    *   1 - Folder
    *   2 - Application Group
    *   3 - Document
    *   4 - SQL Query String
    */
   int action;
   union
   {
      struct
      {
         char *folder_name;
      } folder_perm;
      struct
      {
         ArcCSXitApplGroup appl_grp;
      } appl_grp_perm;
      struct
      {
         ArcCSXitApplGroup appl_grp;
         ArcCSXitDoc doc;
      } doc_perm;
      struct
      {
         ArcCSXitApplGroup appl_grp;
         char *in_sql;
         char *in_sql_r;
         char *out_sql;
         char *out_sql_r;
      } sql_query_perm;
   } u;
} ArcCSXitPermExit;

int
ARSCSXIT_EXPORT
ARSCSXIT_API
PERMEXIT( char *userid, ArcCSXitPermExit *perm_exit, int *access );

/* DKW - LI830 */
/**********************************************************************/
/* UPDTEXIT - Report Definition Update Exit                           */
/*                                                                    */
/*  This exit is for specialized applications and is not normally     */
/*  used.                                                             */
/*                                                                    */
/* INPUT:                                                             */
/*        pFileName                                                   */
/*        Function                                                    */
/*        ApplGrpName                                                 */
/*        ApplName                                                    */
/*        ObjServer                                                   */
/*        StorageNode                                                 */
/*        pJES                                                        */
/*        pIndexerParms                                               */
/*        DataType                                                    */
/*        CCType                                                      */
/*        LRECL                                                       */
/*        RECFM                                                       */
/*        Delim                                                       */
/*                                                                    */
/* OUTPUT:                                                            */
/*        ApplGrpName                                                 */
/*        ApplName                                                    */
/*        ObjServer                                                   */
/*        StorageNode                                                 */
/*        pIndexerParms                                               */
/*        DataType                                                    */
/*        CC                                                          */
/*        CCType                                                      */
/*        LRECL                                                       */
/*        RECFM                                                       */
/*        Delim                                                       */
/*        UpdateAppl                                                  */
/*                                                                    */
/* RETURN_CODE:                                                       */
/*        0         -> Successful                                     */
/*        Otherwise -> Failed                                         */
/*                                                                    */
/**********************************************************************/

#if defined(OS390)
typedef struct _ArsCSXitUpdtExit_JES
{
  void              *JES_SSS2p; /* pointer to SSS2 (SAPI SSOB ext) */
  char               JES_DD[8]; /* DD name allocated to spool file */
} ArsCSXitUpdtExit_JES;
#endif

typedef struct _ArsCSXitUpdtExit
{
   char*              pFileName;
   int                Function;
   char               ApplGrpName[ARCCSXIT_MAX_NAME_SIZE + 1];
   char               ApplName[ARCCSXIT_MAX_NAME_SIZE + 1];
   char               ObjServer[ARCCSXIT_MAX_SERVER_SIZE + 1];
   char               StorageNode[ARCCSXIT_MAX_NAME_SIZE + 1];
   void*              pJES;
   char               IndexerParms[ARCCSXIT_MAX_INDEXER_SIZE + 1];
   ArcCSXitCarCtl     CCType;
   int                LRECL;
   ArcCSXitDocFormat  RECFM;
   int                UpdateAppl;
   char               Delim[ARCCSXIT_MAX_DELIMITER_SIZE + 1];
} ArsCSXitUpdtExit;

int
ARSCSXIT_EXPORT
ARSCSXIT_API
UPDTEXIT( ArsCSXitUpdtExit* updt );
/* DKW - LI830 */

/* DKW - LI832 */
/**********************************************************************/
/* PREPEXIT - Client Retrieval Preview Exit                           */
/*                                                                    */
/*  This exit is used to modify the contents of a document prior      */
/*  retrieving the document                                           */
/*                                                                    */
/* INPUT:                                                             */
/*        pInFileName                                                 */
/*        pOutFileName                                                */
/*        pUserParms                                                  */
/*        pApplGrp                                                    */
/*        pAppl                                                       */
/*        pDoc                                                        */
/*                                                                    */
/* OUTPUT:                                                            */
/*                                                                    */
/* RETURN_CODE:                                                       */
/*        0         -> Successful                                     */
/*        Otherwise -> Failed                                         */
/*                                                                    */
/**********************************************************************/
typedef struct _ArsCSXitPrepExit
{
   char*              pUserid;      /* Logged on userid */
   char*              pInFileName;  /* File name for document data */

   /* File name for modified data */
   char               OutFileName[ARCCSXIT_PATH_MAX + 1];

   char*              pUserParms;   /* User defined parms from appl */
   ArcCSXitApplGroup* pApplGrp;     /* Appl Grp info */
   ArcCSXitAppl*      pAppl;        /* Application info */
   ArcCSXitDoc*       pDoc;         /* Doc handle, field info */
} ArsCSXitPrepExit;

int
ARSCSXIT_EXPORT
ARSCSXIT_API
PREPEXIT( ArsCSXitPrepExit* prep );
/* DKW - LI832 */

#ifdef __cplusplus
}
#endif

#endif
